@@ -39,7 +39,7 @@ class Profile:
             kk = len(pixel_max)
         except TypeError:
             pixel_max = [pixel_max] * len(file_paths)
-        for f in file_paths:
+        for i, f in enumerate(file_paths):
             self.scans.append(Scan(f, parser, q_axis_name, theta_axis_name, pixel_max=pixel_max[i], hot_pixel_threshold=hot_pixel_threshold))
         self.q_vectors = None
         self.reflected_intensity = None
